### Read the [WashingtonPost-specific instructions](https://github.com/WPMedia/clokta/blob/main/INSTRUCTIONS.md) for using clokta.

For users other than Washington Post employees, instructions for using Okta as an open source product can be found [here](INSTRUCTIONS.md).

